@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid = "$Id: graph3d.c,v 1.2 1993/07/27 23:26:37 djm Exp $";
+static char *RCSid = "$Id: graph3d.c%v 3.50.1.9 1993/08/05 05:38:59 woo Exp $";
 #endif
 
 
@@ -54,17 +54,17 @@ static char *RCSid = "$Id: graph3d.c,v 1.2 1993/07/27 23:26:37 djm Exp $";
 #if !defined(u3b2)
 #include <time.h>
 #endif
-#if !defined(sequent) && !defined(apollo)
+#if !defined(sequent) && !defined(apollo) && !defined(alliant)
 #include <limits.h>
 #endif
 #include "plot.h"
 #include "setshow.h"
 
-#ifdef DJGPP
+#if defined(DJGPP)||defined(sun386)
 #define time_t unsigned long
 #endif
 
-#if defined(apollo) || defined(sequent) || defined(u3b2)
+#if defined(apollo) || defined(sequent) || defined(u3b2) || defined(alliant) || defined(sun386)
 #include <sys/types.h> /* typedef long time_t; */
 #endif
 
@@ -718,8 +718,8 @@ static boundary3d(scaling)
     ytop = (scaling ? 1 : ysize) * (t->ymax) - (t->v_char)*5/2 - 1;
     xmiddle = (xright + xleft) / 2;
     ymiddle = (ytop + ybot) / 2;
-    xscaler = (xright - xleft) * 3 / 5;
-    yscaler = (ytop - ybot) * 3 / 5;
+    xscaler = (xright - xleft) * 4 / 7;
+    yscaler = (ytop - ybot) * 4 / 7;
 }
 
 static double dbl_raise(x,y)
@@ -928,7 +928,7 @@ transform_matrix mat;
 		else {
 			(void)(*t->justify_text)(LEFT);
 			(*t->put_text)(x,
-						 y+ybot-3*(t->v_char), tdate);
+						 y+ybot-1*(t->v_char), tdate);
 		}
 		(void)(*t->text_angle)(0);
 	}
